//===============================================================================
// All contents of this file are confidential and copyright (c) Avanade, Inc.
// All rights reserved.
//===============================================================================
//<summary>
// Common routines for general purpose.
//</summary>
//<remarks>
// Author: Avanade Spain, September 2004
//</remarks>
//
// MODULE CONSTANTS
//
//<value>The constant used for the NIF length.</value>
var NIF_LENGTH = 9;
//<value>The constant used for the CIF length.</value>
var CIF_LENGTH = 8;
//<value>The constant used for the NIE length.</value>
var NIE_LENGTH = 10;
//<value>The constant used for the valid CIF letters.</value>
var LETRAS_CIF = "ABCDEFGHKLMNPQS";
//
// MODULE VARIABLES
//
//<value>Global error message.</value>
var m_strErrMsg = "";
//
// MODULE METHODS
//
// <summary>
//	It adds an error message to the error buffer string.
//	The error buffer string is the page global variable "m_strErrMsg".
// </summary>
// <param name="strErrMsg" >Error message string.</param>
// <returns>Nothing.</returns>
function AddToErrorBuffer(strErrMsg)
{	
	if (m_strErrMsg != null)
	{
		if (!(m_strErrMsg.indexOf(strErrMsg) >= 0))
			m_strErrMsg += strErrMsg;		
	}
}

// <summary>
//	It cleans up an specific error message from the error buffer string.
//	The error buffer string is the page global variable "m_strErrMsg".
// </summary>
// <param name="strErrMsg" >Error message string.</param>
// <returns>Nothing.</returns>
function CleanUpErrorBuffer(strErrMsg)
{
	if ((m_strErrMsg != null) && (m_strErrMsg.length > 0))
	{
		var intIndexA = m_strErrMsg.indexOf(strErrMsg);	
		
		if (intIndexA == 0)		
			m_strErrMsg = m_strErrMsg.substring(strErrMsg.length - 1);		
		else
		{
			if (intIndexA > 0)
			{
				var intIndexB = intIndexA + (strErrMsg.length - 1);				
				m_strErrMsg = m_strErrMsg.substring(0, (intIndexA - 1)) + m_strErrMsg.substring(intIndexB + 1);
			}			
		}
	}
}

// <summary>
//	It verifies for blank or non-blank input data. 
// </summary>
// <param name="strData" >Data for checking.</param>
// <returns>Boolean: true, if data is blank; false, otherwise.</returns>
function IsEmpty(strData)
{	
	return((strData.length == 0) || (strData == ""));
}

// <summary>
//	It tests the strYear argument to see whether it is a leap year. 
//	It is leap year if the year divides by 4, but not by 100 except 
//  when it divides by 400
// </summary>
// <param name="strYear" >String year to be tested.</param>
// <returns>Boolean: true, if argument is a leap year; otherwise, false.</returns>
function IsLeapYear (strYear) 
{
	var intYear = parseInt(strYear);
	
	if (isNaN(intYear))
		return(false);
	else
		return((0 == (strYear % 4)) && ((0 != (strYear % 100)) || (0 == (strYear % 400)))); 
}

// <summary>
//	It validates that a string date contains only valid dates.
//  Date separator can be ., -, or /.
//  Ex. dd/mm/yyyy or dd-mm-yyyy or dd.mm.yyyy
// </summary>
// <param name="strDate" >String date to be tested for validity.</param>
// <returns>True if valid, otherwise false.</returns>
function IsValidDate ( strDate )
{
	var objRegExp = /^\d{1,2}(\-|\/|\.)\d{1,2}\1\d{4}$/;
	var blnIsValid = false;
	//
	// Check to see if in correct format
	//	
	if (objRegExp.test(strDate))
	{
		//
		// Find date separator
		//
		var strSeparator = strDate.substring(2,3);
		//
		// Split date into day, month, year		
		//
		var arrayDate = strDate.split(strSeparator); 		
		//
		// Create a lookup for months not equal to Feb.
		//
    var arrayLookup = { 
												'01' : 31, 
												'03' : 31, 
												'04' : 30, 
												'05' : 31,
												'06' : 30,
												'07' : 31,
                        '08' : 31,
                        '09' : 30,
                        '10' : 31,
                        '11' : 30,
                        '12' : 31
                       };		
		var intDay = parseInt(arrayDate[0]);                       
		//
		// Check if month value and day value agree
		//
		if (arrayLookup[arrayDate[1]] != null) 
		{			
			// 
			// Found in lookup table, good date
			//		
      if ((intDay <= arrayLookup[arrayDate[1]]) && (intDay != 0))      
				blnIsValid = true;		
    }	 
    else
    {
			//
			// Check for february
			//
			var intYear = parseInt(arrayDate[2]);
			var intMonth = parseInt(arrayDate[1]);
			if( ((IsLeapYear(intYear) && (intDay <= 29)) || (!IsLeapYear(intYear) && (intDay <= 28))) && (intDay > 0))
				blnIsValid = true;
    }
	}		
	//
	// Function return value
	//
	return(blnIsValid);	
}

// <summary>
//	It returns the days in the month of the "strDate" date parameter .
// </summary>
// <param name="strDate" >String date.</param>
// <returns>Int: the days in the month of the "strDate" date parameter.</returns>
function GetDaysInMonth ( strDate )
{
	// Array for the days in month: 0, January; 1, February and so on...
	var arrDaysInMonth = new Array(31,28,31,30,31,30,31,31,30,31,30,31);
	// Build a date object with the "strDate" param passed in correct format mm/dd/yyyy
	strDate = strDate.substr(3,2) + "/" + strDate.substr(0, 2) + "/" + strDate.substr(6, 4);
	var dtDate = new Date(strDate);	
	// Get the month of the date object built: 0, January; 1, February and so on...
	var intMonth = dtDate.getMonth();	
	// Get the year for the month of the date object built
	var intYear = dtDate.getFullYear();	
	//
	// Check for leap year
	//	
	if (
			((intYear % 4 == 0) && (intYear % 100 != 0)) || 
			(intYear % 400 == 0)
			)
		arrDaysInMonth[1] = 29;	
	//
	// Function return value
	//	
	return(arrDaysInMonth[intMonth]);	
}

// <summary>
//	It validates an email address
// </summary>
// <param name="strEmail" >Email address.</param>
// <returns>bool: true, if it is a valid email address; false otherwise</returns>
function IsValidEmail ( strEmail ) 
{
	var pattern = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
	return pattern.test(strEmail);
}

// <summary>
//	It validates a nif value
// </summary>
// <param name="strNif" >Nif to validate.</param>
// <returns>bool: true, if it is correct; false otherwise</returns>
function ValidateNif ( strNif )
{
	var blnIsValidNif = false;
	
	// Rellenar con 0s por la izquierda si es necesario
	while (strNif.length < NIF_LENGTH)
	{
		strNif = "0" + strNif;
	}
	
	strNif = strNif.toUpperCase();		
	var intNifNumber = parseInt(strNif.substr(0, strNif.length - 1), 10);		
	var strNifLetter = strNif.substr(strNif.length - 1, 1);		
	var intModule = intNifNumber % 23;	
	
	var strLetters = 'TRWAGMYFPDXBNJZSQVHLCKE';				
	var strCheckLetter = strLetters.substring(intModule, intModule + 1);		

	if (strCheckLetter == strNifLetter)
	{	
		blnIsValidNif = true;		
	}	
	//
	// Function return value
	//		
	return(blnIsValidNif);
}

// <summary>
//	Validates a CIF value.
// </summary>
// <param name="strCIF">CIF to validate.</param>
// <returns>bool: true, if it is correct; false otherwise</returns>
function ValidateCIF ( strCIF )
{
	var blnValidCIF = false;
	
	var arrValores = new Array(0,2,4,6,8,1,3,5,7,9); 
	
	var lngTemp = 0; 
	for(intIndex = 2; intIndex <= 6; intIndex += 2) 
	{
		lngTemp = lngTemp + arrValores[parseInt(strCIF.substr(intIndex - 1, 1))];
		lngTemp = lngTemp + parseInt(strCIF.substr(intIndex, 1));
	}

	lngTemp = lngTemp + arrValores[parseInt(strCIF.substr(7, 1))];

	lngTemp = (10 - (lngTemp % 10));

	if (lngTemp == 10)
	{
		blnValidCIF = true;		
	}
	else
	{
		blnValidCIF = true;		
	}	
	
	// Function return value
	return(blnValidCIF);
}

// <summary>
//	Clean Doc ID value from invalid characters.
// </summary>
// <param name="strDocID"> Doc ID to clean: NIF o CIF o NIE.</param>
// <returns>string: the clean doc ID.</returns>
function CleanDocID ( strDocID )
{		
	// Quitar espacios en blanco y los carcteres -, /, _
	var strTempDocID = "";
	for (var intIndex = 0; intIndex < strDocID.length; intIndex++)
	{		
		// Si el carcter es un espacio en blanco, "/", "-" o "_", se lo salta.
		// Si no, monta la cadena carcter a carcter
		if (
				(strDocID.substr(intIndex, 1) != " ") && 
				(strDocID.substr(intIndex, 1) != "/") && 
				(strDocID.substr(intIndex, 1) != "-") && 
				(strDocID.substr(intIndex, 1) != "_")
				)
		{
			strTempDocID += strDocID.substr(intIndex, 1);
		}
	}
	
	// Function return value
	return(strTempDocID);
}

// <summary>
//	Validates the Doc ID value.
// </summary>
// <param name="strDocID"> Doc ID to validate: NIF o CIF o NIE.</param>
// <returns>bool: true, if it is correct; false otherwise</returns>
function ValidateDocID ( strDocID )
{
	var blnValidDocID = false;
	
	// Convertir a maysculas y quitar espacios en blanco y los carcteres -, / y _
	strDocID = CleanDocID(strDocID.toUpperCase());			
	
	// Si el primer carcter es un nmero tratarlo como un NIF		
	if (parseInt(strDocID.substr(0, 1)) || (strDocID.substr(0, 1) == "0"))
	{		
		blnValidDocID = ValidateNif(strDocID);
	}
	else // Es un CIF  NIE
	{		
		// Si es un NIE, procesarlo como un NIF		
		if (strDocID.substr(0, 1) == "X")
		{			
			blnValidDocID = ValidateNif(strDocID.substr(1, strDocID.length - 1));
		}
		else // Es un CIF
		{		
			// Comprobar que tiene los 8 carcteres necesarios
			if (!(strDocID.length < CIF_LENGTH))
			{			
				// Comprobar que comienza por alguna de las letras admitidas por el CIF								
				if (LETRAS_CIF.indexOf(strDocID.substr(0, 1)) >= 0)
				{
					blnValidDocID = ValidateCIF(strDocID);					
				}
			}
		}		
	}
	
	// Function return value
	return(blnValidDocID);
}

// <summary>
// It selects the indicated combo option value according to the passed parameter 
// </summary>
// <param name="strFormName" >The current form name.</param>
// <param name="strComboFieldName" >The combo field name.</param>
// <param name="strComboValue" >The combo field value.</param>
// <returns>Nothing</returns>
function SelectComboOption(
	strFormName, 
	strComboFieldName,  
	strComboFieldValue)														
{
	// Build combo field object
	var objComboField = eval("document.getElementById('" + strFormName + "')." + strComboFieldName);	
	if (objComboField != null)
	{
		if (objComboField.options != null)
		{
			for (intIndex = 0; intIndex < objComboField.options.length; intIndex++)
			{
				if (objComboField.options[intIndex].value == strComboFieldValue)
				{
					objComboField.options[intIndex].selected = true;
					break;
				}
			}
		}
	}
}

// <summary>
//	It makes the roll-over for the image objects.
// </summary>
// <returns>Nothing.</returns>
function SwapImage(e)
{
	var strImgSource = e.getAttribute('src');
  var strImgSourcePath = strImgSource.split("/");
  
  var strFinalImgSource = "";
	if (!(strImgSourcePath[0].indexOf("http:")) > 0)	
		strFinalImgSource = "http:/";	
	else	
		strFinalImgSource = strImgSourcePath[0] + "/" + strImgSourcePath[1];	

	if (strImgSourcePath[strImgSourcePath.length - 1].indexOf("_OFF") > 0)
	{
		var strPrevState = "_OFF";
		var strNewState = "_ON";
	}
	else
	{
		var strPrevState = "_ON";
		var strNewState = "_OFF";
	}

	for (var intIndex = 2; intIndex < strImgSourcePath.length - 1; intIndex++)
	{
			strFinalImgSource = strFinalImgSource + "/" + strImgSourcePath[intIndex];
	}
	
	var strImgFile = strImgSourcePath[strImgSourcePath.length - 1].split(strPrevState);
	strFinalImgSource = strFinalImgSource + "/" + strImgFile[0] + strNewState + strImgFile[1];
	e.setAttribute('src', strFinalImgSource);
}