//===============================================================================
// All contents of this file are confidential and copyright (c) Avanade, Inc.
// All rights reserved.
//===============================================================================
//<summary>
// Parameter management module. It builds an xml in order to pass a collection
// of parameters
//</summary>
//<remarks>
// Author: Avanade Spain, September 2004
//</remarks>
//
// MODULE CONSTANTS
//
//<value>The constant used for the initial param xml structure.</value>
var INITIAL_PARAM_XML = "<NewDataSet></NewDataSet>";
//<value>The constant used for the "NewDataSet" xml node tag.</value>
var NEWDATASET_NODE_TAG = "NewDataSet";
//<value>The constant used for the "Params" xml node tag.</value>
var PARAMS_NODE_TAG = "Params";
//<value>The constant used for the "ParamName" xml node tag.</value>
var PARAM_NAME_NODE_TAG = "ParamName";
//<value>The constant used for the "ParamNode" xml node tag.</value>
var PARAM_VALUE_NODE_TAG = "ParamValue";
//
// MODULE VARIABLES
//
// <value>Param xml string.</value>
var m_strParamXml = "";
//
// MODULE METHODS
//
// <summary>
//   It adds a new param node to the global param xml string in order to build a 
//   xml-formatted parameter list
// </summary>
// <param name="strParamNameNode" type="String">Param name node.</param>
// <param name="strParamValueNode" type="String">Param value node.</param>
// <returns>Boolean: true, if the process is successful; otherwise, false.</returns>
function AddParamNode( 
											 strParamNameNode, 
                       strParamValueNode
                      )
{
	//
  // Check for param xml content
  //
  if (IsEmpty(m_strParamXml))
		m_strParamXml = INITIAL_PARAM_XML;
	
	var objXmlDoc = new ActiveXObject("Msxml2.DOMDocument.3.0");		
  objXmlDoc.async = false;
  
  var blnRetVal = false;	
  if (!objXmlDoc.loadXML(m_strParamXml))  
    m_strParamXml = "";  
  else
  {
    //
    // Create "Param" node below "NewDataSet" root node
    //
    if (objXmlDoc.documentElement == null)    
      m_strParamXml = "";    
    else
    {      
      var objParamNode = objXmlDoc.documentElement.appendChild(objXmlDoc.createElement(PARAMS_NODE_TAG));
      if (objParamNode == null)			
				m_strParamXml = "";      
      else
      {
        //
        // Create "ParamName" node as "Param" node child
        //        
        var objParamNameNode = objParamNode.appendChild(objXmlDoc.createElement(PARAM_NAME_NODE_TAG));
        if (objParamNameNode == null)        
          m_strParamXml = "";        
        else
        {
          // Set the "ParamName" node value
          objParamNameNode.text = strParamNameNode;
          //
          // Create "ParamValue" node as "Param" node child
          //          
          var objParamValueNode = objParamNode.appendChild(objXmlDoc.createElement(PARAM_VALUE_NODE_TAG));
          if (objParamValueNode == null)          
            m_strParamXml = "";          
          else
          {
            // Set the "ParamValue" node value
            objParamValueNode.text = strParamValueNode;
            //
            // Get the param xml new structure
            //
            m_strParamXml = objXmlDoc.xml;            
            blnRetVal = true;
          }
          // Clean up
          objParamValueNode = null;
        } 
        // Clean up
        objParamNameNode = null;
			}
      // Clean up
      objParamNode = null;
    }
  }
  //
  // Clean up
  //
  objXmlDoc = null;
  //
  // Function return value
  //
  return(blnRetVal);
}                      

// <summary>
//   It gets the value of a param node given its node name.
// </summary>
// <param name="strParamNameNode" type="String">Param name node.</param>
// <returns>String: the parameter value for the specific node.</returns>
function CollectParamValue ( strParamNameNode )
{  
  var strParamValue = "";
  if (IsEmpty(m_strParamXml))
    strParamValue = "";
  else
  {
    if (IsEmpty(strParamNameNode))
      strParamValue = "";
    else
		{      
      var objXmlDoc =new ActiveXObject("Msxml2.DOMDocument.3.0");
      objXmlDoc.async = false;
      
      if (!objXmlDoc.loadXML(m_strParamXml))
        strParamValue = "";
      else
      {
        //
        // Check for specific param node searching by param name
        //        
        var strXPath = NEWDATASET_NODE_TAG + "/" + PARAMS_NODE_TAG + "[" + PARAM_NAME_NODE_TAG + "=//" + strParamNameNode + "//]";        
        var objParamNameNode = objXmlDoc.selectSingleNode(strXPath);
        if (objParamNameNode == null)
          strParamValue = "";
        else
        {
          //
          // Get the specific param value
          //
          if (!(objParamNameNode.childNodes.length > 1))
            strParamValue = "";
          else
            strParamValue = objParamNameNode.childNodes.Item(1).text;
        }
        // Clean up
        objParamNameNode = null;
      }
      // Clean up
      objXmlDoc = null;
    }
  }
  //
  // Function return value
  //
  return(strParamValue);
}