//===============================================================================
// All contents of this file are confidential and copyright (c) Avanade, Inc.
// All rights reserved.
//===============================================================================
//<summary>
// It manages the advanced search client validation.
//</summary>
//<remarks>
// Author: Avanade Spain, September 2004
//</remarks>
//
// MODULE CONSTANTS
//
//<value>The constant used for the "strSearch" search parameter.</value>
var FREE_TEXT_KEY = "strSearch";
//<value>The constant used for the "strExactPhrase" search parameter.</value>
var EXACT_PHRASE_KEY = "strExactPhrase";
//<value>The constant used for the "strFreeTextFields" search parameter.</value>
var FREE_TEXT_FIELDS_KEY = "strFreeTextFields";
//<value>The constant used for the "strProfileDoc" search parameter .</value>
var PROFILE_DOC_KEY = "strProfileDoc";
//<value>The constant used for the "strStartDate" search parameter.</value>
var START_DATE_KEY = "strStartDate";
//<value>The constant used for the "strEndDate" search parameter.</value>
var END_DATE_KEY = "strEndDate";
//<value>The constant used for the "strExtensionFile" search parameter.</value>
var EXTENSION_FILE_KEY = "strExtensionFile";
//<value>The constant used for the "lngLowerFileSize" search parameter.</value>
var LOWER_FILE_SIZE_KEY = "lngLowerFileSize";
//<value>The constant used for the "lngUpperFileSize" search parameter.</value>
var UPPER_FILE_SIZE_KEY = "lngUpperFileSize";
//<value>The constant used for the "strOrderBy" search parameter.</value>
var ORDER_BY_KEY = "strOrderBy";
//<value>The constant used for the "strOrderByType" search parameter.</value>
var ORDER_BY_TYPE_KEY = "strOrderByType";
//
// MODULE VARIABLES
//
//<value>Global coeficient.</value>
var m_intCoefficient = 1024;
//
// MODULE METHODS
//
// <summary>
//	It redirects to AdvancedSearch page
// </summary>
// <param name="strAdvancedSearchUrl" type="string">The advanced search url string.</param>
// <returns>Nothing</returns>
function GoToAdvancedSearch ( strAdvancedSearchUrl )
{
	var strUrlParam = "";
	if (document.getElementById("formBusquedaSimple") != null)
	{
		if (
				(document.getElementById("formBusquedaSimple").txtSearch != null) && 
				(!IsEmpty(document.getElementById("formBusquedaSimple").txtSearch.value))
			 )
			strUrlParam = "?txtFreeText=" + document.getElementById("formBusquedaSimple").txtSearch.value;
	}
	window.location.href = strAdvancedSearchUrl + strUrlParam;
}

// <summary>
//	It validates the simple search form. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateSimpleSearchForm()
{
	var blnIsValid = false;
	if (document.getElementById("formBusquedaSimple") != null)
	{
		if (
				(document.getElementById("formBusquedaSimple").txtSearch != null) && 
				(!IsEmpty(document.getElementById("formBusquedaSimple").txtSearch.value))
			 )		
		{
			blnIsValid = true;
			
			// Add "strSearch" param node to param xml string
			m_strParamXml = "";
			var blnRetVal = false;
			blnRetVal = AddParamNode(FREE_TEXT_KEY, document.getElementById("formBusquedaSimple").txtSearch.value);	
			if (document.getElementById("formBusquedaSimple").txtParamXml != null)
				document.getElementById("formBusquedaSimple").txtParamXml.value = m_strParamXml;
		}
		else		
		{
			// Clean up xml param form field
			if (document.getElementById("formBusquedaSimple").txtParamXml != null)
				document.getElementById("formBusquedaSimple").txtParamXml.value = "";		
				
			alert("Por favor, debe rellenar el campo 'BUSCAR'");				
		}	
	}
	//
	// Function return value
	//
	return(blnIsValid);
}	

// <summary>
//	It validates the advanced search free text filter. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateFreeTextFilter()
{
	//
	// Check for free text field
	//
	var blnIsValid = false;		
	if (document.getElementById("formBusquedaAvanzada").txtFreeText != null)
	{
		if (IsEmpty(document.getElementById("formBusquedaAvanzada").txtFreeText.value))
		{			
			blnIsValid = false;
			// Add to error buffer
			AddToErrorBuffer("Por favor, debe rellenar el campo 'Buscar texto'\r");		
		}
		else
		{		
			blnIsValid = true;
			// Clean up error buffer
			CleanUpErrorBuffer("Por favor, debe rellenar el campo 'Buscar texto'\r");
		}
		//
		// Check for fields where to search for free text
		//
		var blnFreeTextFields = false;
		if (document.getElementById("formBusquedaAvanzada").rbFreeTextFields != null)
		{
			if (document.getElementById("formBusquedaAvanzada").rbFreeTextFields[0].checked)
			{
				blnFreeTextFields = true;
				// Clean up error buffer
				CleanUpErrorBuffer("Por favor, debe marcar 'Ttulo', 'Descripcin', y/o 'Palabras clave'\r");
			}
			else
			{
				if (document.getElementById("formBusquedaAvanzada").rbFreeTextFields[1].checked)
				{										
					if ((document.getElementById("formBusquedaAvanzada").chkFreeTextTitle != null) && (document.getElementById("formBusquedaAvanzada").chkFreeTextTitle.checked))
						blnFreeTextFields = true;
							
					if ((document.getElementById("formBusquedaAvanzada").chkFreeTextDescription != null) && (document.getElementById("formBusquedaAvanzada").chkFreeTextDescription.checked))
						blnFreeTextFields = true;
						
					if ((document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords != null) && (document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords.checked))
						blnFreeTextFields = true;						
						
					if (blnFreeTextFields)
					{						
						// Clean up error buffer
						CleanUpErrorBuffer("Por favor, debe marcar 'Ttulo', 'Descripcin', y/o 'Palabras clave'\r");
					}
					else
					{						
						// Add to error buffer
						AddToErrorBuffer("Por favor, debe marcar 'Ttulo', 'Descripcin', 'Autor' y/o 'Vnculo'\r");
					}						
				}
			}
		}			
	}
	//
	// Function return value
	//		
	return((blnIsValid && blnFreeTextFields));
}

// <summary>
//	It validates the advanced search profile document filter. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateProfileDocFilter()
{
	var blnIsValid = false;	
	
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		if (document.getElementById("formBusquedaAvanzada").rbProfileDoc != null)
		{
			if (document.getElementById("formBusquedaAvanzada").rbProfileDoc[0].checked)		
			{
				blnIsValid = true;		
				// Clean up error buffer
				CleanUpErrorBuffer("Por favor, debe marcar 'Notas de prensa', 'Legislacin' y/o 'Empleo'\r");
			}
			else
			{
				if (document.getElementById("formBusquedaAvanzada").rbProfileDoc[1].checked)
				{
					var blnProfileDocOptions = false;
					
					if ((document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc != null) && (document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc.checked))
						blnProfileDocOptions = true;
						
					if ((document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc != null) && (document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc.checked))
						blnProfileDocOptions	= true;
					
					if ((document.getElementById("formBusquedaAvanzada").chkJobProfileDoc != null) && (document.getElementById("formBusquedaAvanzada").chkJobProfileDoc.checked))
						blnProfileDocOptions	= true;
					
					if (blnProfileDocOptions)
					{						
						blnIsValid = true;
						// Clean up error buffer
						CleanUpErrorBuffer("Por favor, debe marcar 'Notas de prensa', 'Legislacin' y/o 'Empleo'\r");											
					}
					else							
					{
						blnIsValid = false;						
						// Add to error buffer
						AddToErrorBuffer("Por favor, debe marcar 'Notas de prensa', 'Legislacin' y/o 'Empleo'\r");						
					}
				}			
			}
		}
	}
	//
	// Function return value
	//
	return(blnIsValid);	
}

// <summary>
//	It validates the advanced search extension file filter. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateExtensionFileFilter()
{
	var blnIsValid = false;
		
	if (document.getElementById("formBusquedaAvanzada") != null)
	{	
		if (document.getElementById("formBusquedaAvanzada").rbExtensionFile != null)
		{
			if (document.getElementById("formBusquedaAvanzada").rbExtensionFile[0].checked)		
			{
				blnIsValid = true;		
				// Clean up error buffer
				CleanUpErrorBuffer("Por favor, debe marcar 'HTM/HTML', 'PDF', 'DOC' y/o 'XLS'\r");					
			}
			else
			{
				if (document.getElementById("formBusquedaAvanzada").rbExtensionFile[1].checked)
				{
					var blnExtensionFileOptions = false;
					
					if ((document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile != null) && (document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile.checked))
						blnExtensionFileOptions = true;
						
					if ((document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile != null) && (document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile.checked))
						blnExtensionFileOptions	= true;
					
					if ((document.getElementById("formBusquedaAvanzada").chkDocExtensionFile != null) && (document.getElementById("formBusquedaAvanzada").chkDocExtensionFile.checked))
						blnExtensionFileOptions	= true;
						
					if ((document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile != null) && (document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile.checked))
						blnExtensionFileOptions = true;							
					
					if (blnExtensionFileOptions)
					{
						blnIsValid = true;
						// Clean up error buffer
						CleanUpErrorBuffer("Por favor, debe marcar 'HTM/HTML', 'PDF', 'DOC' y/o 'XLS'\r");								
					}
					else							
					{				
						blnIsValid = false;		
						// Add to error  buffer
						AddToErrorBuffer("Por favor, debe marcar 'HTM/HTML', 'PDF', 'DOC' y/o 'XLS'\r");						
					}
				}			
			}
		}
	}
	//
	// Function return value
	//	
	return(blnIsValid);	
}

// <summary>
//	It validates the advanced search order by filter. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateOrderByFilter()
{
	var blnIsValid = false;	
	
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		if (document.getElementById("formBusquedaAvanzada").rbOrderBy != null)
		{
			for (var intIndex = 0; intIndex < document.getElementById("formBusquedaAvanzada").rbOrderBy.length; intIndex++)
			{
				if (document.getElementById("formBusquedaAvanzada").rbOrderBy[intIndex].checked)
				{
					blnIsValid = true;
					break;
				}
			}
			
			if (blnIsValid)
			{	
				// Clean error buffer
				CleanUpErrorBuffer("Por favor, debe indicar el concepto de ordenacin de resultados\r");
				
				if (document.getElementById("formBusquedaAvanzada").rbOrderByType != null)
				{
					for (var intIndex = 0; document.getElementById("formBusquedaAvanzada").rbOrderByType.length; intIndex++)
					{
						blnIsValid = true;
						break;
					}
					
					if (blnIsValid)
					{
						// Clean up error buffer	
						CleanUpErrorBuffer("Por favor, debe indicar el tipo de ordenacin deseada\r");
					}
					else
					{
						blnIsValid = false;
						// Add to error buffer
						AddToErrorBuffer("Por favor, debe indicar el tipo de ordenacin deseada\r");
					}
				}
			}
			else
			{
				blnIsValid = false;
				// Add to error buffer
				AddToErrorBuffer("Por favor, debe indicar el concepto de ordenacin de resultados\r");
			}
		}
	}
	//
	// Function return value
	//
	return(blnIsValid);	
}

// <summary>
//	It gets the lower file size filter.
// </summary>
// <returns>Int: the lower file size.</returns>
function GetLowerFileSize()
{
	var intLowerFileSize = 0;
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		//
		// Calculate coefficient
		//
		var intCoefficient = 1024;
		if (
				(document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat != null) && 
				(document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat.options.length > 0)				
				)
		{
			if (document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat.options[document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat.selectedIndex].value.toLowerCase() == "kb")
				intCoefficient = 1024;			
			else
			{
				if (document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat.options[document.getElementById("formBusquedaAvanzada").cboLowerFileSizeFormat.selectedIndex].value.toLowerCase() == "mb")
					intCoefficient = 1024 * 1024;	
			}
		}
		//
		// Set lower file size hidden field value
		//
		if ( 
				(document.getElementById("formBusquedaAvanzada").cboLowerFileSize != null) && 
				(document.getElementById("formBusquedaAvanzada").cboLowerFileSize.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboLowerFileSize.options.length > 0)				
				)
		{					
			intLowerFileSize = intCoefficient * parseInt(document.getElementById("formBusquedaAvanzada").cboLowerFileSize.options[document.getElementById("formBusquedaAvanzada").cboLowerFileSize.selectedIndex].value);
		}		
	}
	//
	// Function return value
	//
	return(intLowerFileSize);	
}

// <summary>
//	It gets the upper file size filter.
// </summary>
// <returns>Int: the lower file size.</returns>
function GetUpperFileSize()
{
	var intUpperFileSize = 0;
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		//
		// Calculate coefficient
		//
		var intCoefficient = 1024;
		if (
				(document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat != null) && 
				(document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat.options.length > 0)				
				)
		{
			if (document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat.options[document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat.selectedIndex].value.toLowerCase() == "kb")
				intCoefficient = 1024;			
			else
			{
				if (document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat.options[document.getElementById("formBusquedaAvanzada").cboUpperFileSizeFormat.selectedIndex].value.toLowerCase() == "mb")
					intCoefficient = 1024 * 1024;	
			}
		}
		//
		// Set upper file size hidden field value
		//
		if ( 
				(document.getElementById("formBusquedaAvanzada").cboUpperFileSize != null) && 
				(document.getElementById("formBusquedaAvanzada").cboUpperFileSize.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboUpperFileSize.options.length > 0)				
				)
		{					
			intUpperFileSize = intCoefficient * parseInt(document.getElementById("formBusquedaAvanzada").cboUpperFileSize.options[document.getElementById("formBusquedaAvanzada").cboUpperFileSize.selectedIndex].value);
		}		
	}
	//
	// Function return value
	//
	return(intUpperFileSize);	
}

// <summary>
//	It validates the advanced search file size filter. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateFileSizeRange()
{
	var blnIsValid = false;
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		//
		// Get lower file size 
		//
		if (document.getElementById("formBusquedaAvanzada").txtLowerFileSize != null)		
			document.getElementById("formBusquedaAvanzada").txtLowerFileSize.value = GetLowerFileSize();		
		//
		// Get upper file size
		//
		if (document.getElementById("formBusquedaAvanzada").txtUpperFileSize != null)		
			document.getElementById("formBusquedaAvanzada").txtUpperFileSize.value = GetUpperFileSize();
		
		if (
				(parseInt(document.getElementById("formBusquedaAvanzada").txtLowerFileSize.value) >= 0) &&  
				(parseInt(document.getElementById("formBusquedaAvanzada").txtUpperFileSize.value) >= 0)
				)
			blnIsValid = true;
	}
	//
	// Function return value
	//
	return(blnIsValid);
}

// <summary>
//	It gets the start date filter.
// </summary>
// <returns>String: the start date filter.</returns>
function GetStartDate()
{
	var strStartDate = "";	
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		//
		// Get start date day
		//
		var strStartDateDay = "";
		if (
				(document.getElementById("formBusquedaAvanzada").cboStartDateDay != null) && 
				(document.getElementById("formBusquedaAvanzada").cboStartDateDay.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboStartDateDay.length > 0) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").cboStartDateDay.options[document.getElementById("formBusquedaAvanzada").cboStartDateDay.selectedIndex].value))
			 )		
			strStartDateDay = document.getElementById("formBusquedaAvanzada").cboStartDateDay.options[document.getElementById("formBusquedaAvanzada").cboStartDateDay.selectedIndex].value;				
		//
		// Get start date month
		//
		var strStartDateMonth = "";
		if (
				(document.getElementById("formBusquedaAvanzada").cboStartDateMonth != null) && 
				(document.getElementById("formBusquedaAvanzada").cboStartDateMonth.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboStartDateMonth.length > 0) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").cboStartDateMonth.options[document.getElementById("formBusquedaAvanzada").cboStartDateMonth.selectedIndex].value))
			)	
			strStartDateMonth = document.getElementById("formBusquedaAvanzada").cboStartDateMonth.options[document.getElementById("formBusquedaAvanzada").cboStartDateMonth.selectedIndex].value;			
		//
		// Get start date year
		//			
		var strStartDateYear = "";
		if (
				(document.getElementById("formBusquedaAvanzada").cboStartDateYear != null) && 
				(document.getElementById("formBusquedaAvanzada").cboStartDateYear.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboStartDateYear.length > 0) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").cboStartDateYear.options[document.getElementById("formBusquedaAvanzada").cboStartDateYear.selectedIndex].value))
				)
			strStartDateYear = document.getElementById("formBusquedaAvanzada").cboStartDateYear.options[document.getElementById("formBusquedaAvanzada").cboStartDateYear.selectedIndex].value;		
		//
		// Build the start date
		//			
		if (!IsEmpty(strStartDateDay) && !IsEmpty(strStartDateMonth) && !IsEmpty(strStartDateYear))
			strStartDate = strStartDateDay + "/" + strStartDateMonth + "/" + strStartDateYear;
	}
	//
	// Function return value
	//		
	return(strStartDate);
}

// <summary>
//	It gets the end date filter.
// </summary>
// <returns>String: the end date filter.</returns>
function GetEndDate()
{
	var strEndDate = "";	
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		//
		// Get End date day
		//
		var strEndDateDay = "";
		if (
				(document.getElementById("formBusquedaAvanzada").cboEndDateDay != null) && 
				(document.getElementById("formBusquedaAvanzada").cboEndDateDay.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboEndDateDay.length > 0) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").cboEndDateDay.options[document.getElementById("formBusquedaAvanzada").cboEndDateDay.selectedIndex].value))
			 )
			strEndDateDay = document.getElementById("formBusquedaAvanzada").cboEndDateDay.options[document.getElementById("formBusquedaAvanzada").cboEndDateDay.selectedIndex].value;
		//
		// Get end date month
		//
		var strEndDateMonth = "";
		if (
				(document.getElementById("formBusquedaAvanzada").cboEndDateMonth != null) && 
				(document.getElementById("formBusquedaAvanzada").cboEndDateMonth.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboEndDateMonth.length > 0) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").cboEndDateMonth.options[document.getElementById("formBusquedaAvanzada").cboEndDateMonth.selectedIndex].value))
		)
			strEndDateMonth = document.getElementById("formBusquedaAvanzada").cboEndDateMonth.options[document.getElementById("formBusquedaAvanzada").cboEndDateMonth.selectedIndex].value;
		//
		// Get end date year
		//			
		var strEndDateYear = "";
		if (
				(document.getElementById("formBusquedaAvanzada").cboEndDateYear != null) && 
				(document.getElementById("formBusquedaAvanzada").cboEndDateYear.options != null) && 
				(document.getElementById("formBusquedaAvanzada").cboEndDateYear.length > 0) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").cboEndDateYear.options[document.getElementById("formBusquedaAvanzada").cboEndDateYear.selectedIndex].value))
		)
			strEndDateYear = document.getElementById("formBusquedaAvanzada").cboEndDateYear.options[document.getElementById("formBusquedaAvanzada").cboEndDateYear.selectedIndex].value;		
		//
		// Build the End date
		//	
		if (!IsEmpty(strEndDateDay) && !IsEmpty(strEndDateMonth) && !IsEmpty(strEndDateYear))		
			strEndDate = strEndDateDay + "/" + strEndDateMonth + "/" + strEndDateYear			 
	}
	//
	// Function return value
	//		
	return(strEndDate);
}

// <summary>
//	It validates the advanced search date filter. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateDateFilter()
{
	var blnIsValid = false;
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		if (document.getElementById("formBusquedaAvanzada").txtStartDate != null)
		{
			// 
			// Validate start date form field filter
			//
			document.getElementById("formBusquedaAvanzada").txtStartDate.value = GetStartDate();						
			var blnStartDateIsValid = false;
			if (
					(IsEmpty(document.getElementById("formBusquedaAvanzada").txtStartDate.value)) ||
					((!IsEmpty(document.getElementById("formBusquedaAvanzada").txtStartDate.value)) && (IsValidDate(document.getElementById("formBusquedaAvanzada").txtStartDate.value)))
					)
			{				
				blnStartDateIsValid = true;
				// Clean up error buffer
				CleanUpErrorBuffer("Por favor, debe introducir una fecha 'POSTERIOR A' vlida\r");
			}
			else
			{
				// Add to error buffer
				AddToErrorBuffer("Por favor, debe introducir una fecha 'POSTERIOR A' vlida\r");
			}			
			//
			// Validate end date form field filter
			//
			document.getElementById("formBusquedaAvanzada").txtEndDate.value = GetEndDate();						
			var blnEndDateIsValid = false;
			if (
					(IsEmpty(document.getElementById("formBusquedaAvanzada").txtEndDate.value)) ||
					((!IsEmpty(document.getElementById("formBusquedaAvanzada").txtEndDate.value)) && (IsValidDate(document.getElementById("formBusquedaAvanzada").txtEndDate.value)))
					)
			{			
				blnEndDateIsValid = true;
				// Clean up error buffer
				CleanUpErrorBuffer("Por favor, debe introducir una fecha 'ANTERIOR A' vlida\r");
			}
			else
			{
				// Add to error buffer
				AddToErrorBuffer("Por favor, debe introducir una fecha 'ANTERIOR A' vlida\r");
			}									
			//
			// Validate date range filter
			//			
			blnIsValid = (blnStartDateIsValid && blnEndDateIsValid);						
		}				
	}
	//
	// Function return value
	//	
	return(blnIsValid);	
}

// <summary>
//	It validates the advanced search form. 
// </summary>
// <returns>Boolean: true, if the validation is successful; false, otherwise.</returns>
function ValidateAdvancedSearchForm()
{
	var blnIsValid = false;	
	
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		//
		// Validate free text filter
		//	
		var blnFreeTextFilterIsValid = false;
		if (ValidateFreeTextFilter())
			blnFreeTextFilterIsValid = true;	
		//
		// Validate date range filter
		//
		var blnDateRangeIsValid = false;
		if (ValidateDateFilter())
			blnDateRangeIsValid = true;
		//
		// Validate profile doc filter
		//
		var blnProfileDocFilterIsValid = false;
		if (ValidateProfileDocFilter())
			blnProfileDocFilterIsValid = true;
		//
		// Validate extension file filter
		//
		var blnExtensionFileFilterIsValid = false;
		if (ValidateExtensionFileFilter())
			blnExtensionFileFilterIsValid = true;
		//
		// Validate order filter		
		//
		var blnOrderByFilterIsValid = false;
		if (ValidateOrderByFilter())
			blnOrderByFilterIsValid = true;
		//
		// Validate file size filter
		//
		var blnFileSizeRangeFilterIsValid = false;
		if (ValidateFileSizeRange())
			blnFileSizeRangeFilterIsValid = true;
		
		blnIsValid = blnFreeTextFilterIsValid && 
								 blnDateRangeIsValid && 
								 blnProfileDocFilterIsValid &&
								 blnExtensionFileFilterIsValid	&& 	
								 blnFileSizeRangeFilterIsValid && 
								 blnOrderByFilterIsValid						 
		
		if ((!blnIsValid) && (m_strErrMsg.length > 0))
		{
			// Clean up xml param form field
			if (document.getElementById("formBusquedaAvanzada").txtParamXml != null)
				document.getElementById("formBusquedaAvanzada").txtParamXml.value = "";
				
			// Display error message
			alert(m_strErrMsg);		
		}
		else		
		{
			// Fill in xml param form field
			document.getElementById("formBusquedaAvanzada").txtParamXml.value = BuildParamXml();					
		}
	}
	//
	// Function return value
	//
	return(blnIsValid);
}

// <summary>
//	It adds the "strSearch" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddFreeTextToParamXml()
{
	if (
			(document.getElementById("formBusquedaAvanzada").txtFreeText != null) && 
			(!IsEmpty(document.getElementById("formBusquedaAvanzada").txtFreeText.value))
			)		
	{
		var blnRetVal = false;					
		blnRetVal = AddParamNode(FREE_TEXT_KEY, document.getElementById("formBusquedaAvanzada").txtFreeText.value);	
		
		// The "strFreeTextFields" param node depends on the "strSearch" param node
		if (blnRetVal)
			m_strParamXml = AddFreeTextFieldsToParamXml();
	}
	// 
	// Function return value
	//
	return(m_strParamXml);	
}

// <summary>
//	It adds the "strFreeTextFields" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddFreeTextFieldsToParamXml()
{
	//
	// Add "strFreeTextFields" param node to param xml
	//
	if (
			(document.getElementById("formBusquedaAvanzada").rbFreeTextFields != null) && 
			(document.getElementById("formBusquedaAvanzada").rbFreeTextFields[1].checked)
			)
	{		
		var strFreeTextFieldValues = "";
		// Add "title" free text field
		if (
				(document.getElementById("formBusquedaAvanzada").chkFreeTextTitle != null) && 
				(document.getElementById("formBusquedaAvanzada").chkFreeTextTitle.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkFreeTextTitle.value))
				)
		{
			if (IsEmpty(strFreeTextFieldValues))
				strFreeTextFieldValues += document.getElementById("formBusquedaAvanzada").chkFreeTextTitle.value;
			else
				strFreeTextFieldValues += "," + document.getElementById("formBusquedaAvanzada").chkFreeTextTitle.value;
		}	 			
		
		// Add "description" free text field			
		if (
				(document.getElementById("formBusquedaAvanzada").chkFreeTextDescription != null) && 
				(document.getElementById("formBusquedaAvanzada").chkFreeTextDescription.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkFreeTextDescription.value))
				)
		{
			if (IsEmpty(strFreeTextFieldValues))
				strFreeTextFieldValues += document.getElementById("formBusquedaAvanzada").chkFreeTextDescription.value;
			else
				strFreeTextFieldValues += "," + document.getElementById("formBusquedaAvanzada").chkFreeTextDescription.value;
		}	 		
		
		// Aadir la bsqueda de texto libre basada en las palabras clave ("keywords")
		if (
				(document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords != null) && 
				(document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords.value))
				)
		{
			if (IsEmpty(strFreeTextFieldValues))
				strFreeTextFieldValues += document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords.value;
			else
				strFreeTextFieldValues += "," + document.getElementById("formBusquedaAvanzada").chkFreeTextKeywords.value;
		}	 				
						
		if (!IsEmpty(strFreeTextFieldValues))
		{
			var blnRetVal = false;
			blnRetVal = AddParamNode(FREE_TEXT_FIELDS_KEY, strFreeTextFieldValues);				
		}
	}
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strStartDate" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddStartDateToParamXml()
{
	if ( 
			(document.getElementById("formBusquedaAvanzada").txtStartDate != null) && 
			(!IsEmpty(document.getElementById("formBusquedaAvanzada").txtStartDate.value))
			)
	{
		var blnRetVal = false;		
		blnRetVal = AddParamNode(START_DATE_KEY, document.getElementById("formBusquedaAvanzada").txtStartDate.value);	
	}			
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strEndDate" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddEndDateToParamXml()
{
	if ( 
			(document.getElementById("formBusquedaAvanzada").txtEndDate != null) && 
			(!IsEmpty(document.getElementById("formBusquedaAvanzada").txtEndDate.value))
			)
	{
		var blnRetVal = false;		
		blnRetVal = AddParamNode(END_DATE_KEY, document.getElementById("formBusquedaAvanzada").txtEndDate.value);	
	}			
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strProfileDoc" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddProfileDocToParamXml()
{
	if (
			(document.getElementById("formBusquedaAvanzada").rbProfileDoc != null) && 
			(document.getElementById("formBusquedaAvanzada").rbProfileDoc[1].checked)
		 )
	{
		var strProfileDocValues = "";
		// Add "news" profile doc
		if (
				(document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc != null) && 
				(document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc.value))
				)
		{
			if (IsEmpty(strProfileDocValues))
				strProfileDocValues += document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc.value;
			else
				strProfileDocValues += "," + document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc.value;
		}	 		
		
		// Add "legislation" profile doc
		if (
				(document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc != null) && 
				(document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc.value))
				)
		{
			if (IsEmpty(strProfileDocValues))
				strProfileDocValues += document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc.value;
			else
				strProfileDocValues += "," + document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc.value;
		}			
		
		// Add "job" profile doc
		if (
				(document.getElementById("formBusquedaAvanzada").chkJobProfileDoc != null) && 
				(document.getElementById("formBusquedaAvanzada").chkJobProfileDoc.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkJobProfileDoc.value))
				)
		{
			if (IsEmpty(strProfileDocValues))
				strProfileDocValues += document.getElementById("formBusquedaAvanzada").chkJobProfileDoc.value;
			else
				strProfileDocValues += "," + document.getElementById("formBusquedaAvanzada").chkJobProfileDoc.value;
		}					
		
		if (!IsEmpty(strProfileDocValues))
		{
			var blnRetVal = false;
			blnRetVal = AddParamNode(PROFILE_DOC_KEY, strProfileDocValues);				
		}						
	}
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strExtensionFile" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddExtensionFileToParamXml()
{
	if (			
			(document.getElementById("formBusquedaAvanzada").rbExtensionFile != null) && 
			(document.getElementById("formBusquedaAvanzada").rbExtensionFile[1].checked)
		 )
	{
		var strExtensionFileValues = "";
		// Add "htm/html" extension file
		if (
				(document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile != null) && 
				(document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile.value))
				)
		{
			if (IsEmpty(strExtensionFileValues))
				strExtensionFileValues += document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile.value;
			else
				strExtensionFileValues += "," + document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile.value;
		}							
		
		// Add "pdf" extension file
		if (
				(document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile != null) && 
				(document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile.value))
				)
		{
			if (IsEmpty(strExtensionFileValues))
				strExtensionFileValues += document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile.value;
			else
				strExtensionFileValues += "," + document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile.value;
		}							
		
		// Add "doc" extension file
		if (
				(document.getElementById("formBusquedaAvanzada").chkDocExtensionFile != null) && 
				(document.getElementById("formBusquedaAvanzada").chkDocExtensionFile.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkDocExtensionFile.value))
				)
		{
			if (IsEmpty(strExtensionFileValues))
				strExtensionFileValues += document.getElementById("formBusquedaAvanzada").chkDocExtensionFile.value;
			else
				strExtensionFileValues += "," + document.getElementById("formBusquedaAvanzada").chkDocExtensionFile.value;
		}							
		
		// Add "xls" extension file
		if (
				(document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile != null) && 
				(document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile.checked) && 
				(!IsEmpty(document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile.value))
				)
		{
			if (IsEmpty(strExtensionFileValues))
				strExtensionFileValues += document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile.value;
			else
				strExtensionFileValues += "," + document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile.value;
		}					
		
		if (!IsEmpty(strExtensionFileValues))
		{
			var blnRetVal = false;
			blnRetVal = AddParamNode(EXTENSION_FILE_KEY, strExtensionFileValues);				
		}						
	}
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strLowerFileSize" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddLowerFileSizeToParamXml()
{
	if (
			(document.getElementById("formBusquedaAvanzada").txtLowerFileSize != null) && 
			(!IsEmpty(document.getElementById("formBusquedaAvanzada").txtLowerFileSize.value)) && 
			(parseInt(document.getElementById("formBusquedaAvanzada").txtLowerFileSize.value) > 0)
		 )
	{
		var blnRetVal = false;
		blnRetVal = AddParamNode(LOWER_FILE_SIZE_KEY, document.getElementById("formBusquedaAvanzada").txtLowerFileSize.value);
	}
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strUpperFileSize" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddUpperFileSizeToParamXml()
{
	if (
			(document.getElementById("formBusquedaAvanzada").txtUpperFileSize != null) && 
			(!IsEmpty(document.getElementById("formBusquedaAvanzada").txtUpperFileSize.value)) &&
			(document.getElementById("formBusquedaAvanzada").txtUpperFileSize.value > 0)
		 )
	{
		var blnRetVal = false;
		blnRetVal = AddParamNode(UPPER_FILE_SIZE_KEY, document.getElementById("formBusquedaAvanzada").txtUpperFileSize.value);
	}
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It adds the "strOrderBy" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddOrderByToParamXml()
{
	if (
			(document.getElementById("formBusquedaAvanzada").rbOrderBy != null) &&
			(document.getElementById("formBusquedaAvanzada").rbOrderBy.length > 0)
		 )
	{
		var blnRetVal = false;
		for (var intIndex = 0; intIndex < document.getElementById("formBusquedaAvanzada").rbOrderBy.length; intIndex++)
		{
			if (
					(document.getElementById("formBusquedaAvanzada").rbOrderBy[intIndex].checked) && 
					(!IsEmpty(document.getElementById("formBusquedaAvanzada").rbOrderBy[intIndex].value))
				 )
			
			{				
				blnRetVal = AddParamNode(ORDER_BY_KEY, document.getElementById("formBusquedaAvanzada").rbOrderBy[intIndex].value);		
				break;
			}
		}
		// The "strOrderByType" param node depends of "strOrderBy" param node
		if (blnRetVal)
			AddOrderByTypeToParamXml(m_strParamXml);
	}
	//
	// Function return value
	// 
	return(m_strParamXml);
}

// <summary>
//	It adds the "strOrderByType" node to param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function AddOrderByTypeToParamXml()
{
	if (
			(document.getElementById("formBusquedaAvanzada").rbOrderByType != null) &&
			(document.getElementById("formBusquedaAvanzada").rbOrderByType.length > 0)			
		 )		
	{
		var blnRetVal = false;
		for (var intIndex = 0; intIndex < document.getElementById("formBusquedaAvanzada").rbOrderByType.length; intIndex++)
		{
			if (
					(document.getElementById("formBusquedaAvanzada").rbOrderByType[intIndex].checked) && 
					(!IsEmpty(document.getElementById("formBusquedaAvanzada").rbOrderByType[intIndex].value))
				 )
			
			{				
				blnRetVal = AddParamNode(ORDER_BY_TYPE_KEY, document.getElementById("formBusquedaAvanzada").rbOrderByType[intIndex].value);		
				break;
			}
		}	
	}
	//
	// Function return value
	//
	return(m_strParamXml);
}

// <summary>
//	It builds the param xml string. 
// </summary>
// <returns>String: if not is empty, the param xml string; otherwise, null string.</returns>
function BuildParamXml()
{	
	if(document.getElementById("formBusquedaAvanzada") != null)
	{	
		m_strParamXml = "";
		// Add "strSearch" param node to param xml		
		m_strParamXml = AddFreeTextToParamXml();		
		
		// Add "strStartDate" param node to param xml	
		m_strParamXml = AddStartDateToParamXml();
		// Add "strEndDate" param node to param xml	
		m_strParamXml = AddEndDateToParamXml();
		// Add "strProfileDoc" param node to param xml		
		m_strParamXml = AddProfileDocToParamXml();
		// Add "strExtensionFile" param node to param xml		
		m_strParamXml = AddExtensionFileToParamXml();
		// Add "strLowerFileSize" param node to param xml
		m_strParamXml = AddLowerFileSizeToParamXml();
		// Add "strUpperFileSize" param node to param xml
		m_strParamXml = AddUpperFileSizeToParamXml();		
		// Add "strOrderBy" param node to param xml
		m_strParamXml = AddOrderByToParamXml();	
	}	
	//
	// Function return value
	//	
	return(m_strParamXml);
}
//
// MODULE EVENT HANDLERS
//
function rbFreeTextFields_onclick()
{
	if (document.getElementById("formBusquedaAvanzada") != null)	
	{
		if (document.getElementById("formBusquedaAvanzada").rbFreeTextFields != null)
		{
			if (document.getElementById("formBusquedaAvanzada").rbFreeTextFields[0].checked)
			{
				if (document.getElementById("formBusquedaAvanzada").chkFreeTextTitle != null)
					document.getElementById("formBusquedaAvanzada").chkFreeTextTitle.checked = false;
					
				if (document.getElementById("formBusquedaAvanzada").chkFreeTextDescription != null)
					document.getElementById("formBusquedaAvanzada").chkFreeTextDescription.checked = false; 
					
				if (document.getElementById("formBusquedaAvanzada").chkFreeTextAuthor != null)
					document.getElementById("formBusquedaAvanzada").chkFreeTextAuthor.checked = false;
					
				if (document.getElementById("formBusquedaAvanzada").chkFreeTextLink != null)
					document.getElementById("formBusquedaAvanzada").chkFreeTextLink.checked = false;				
			}
		}
	}
}

function rbProfileDoc_onclick()
{
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		if (document.getElementById("formBusquedaAvanzada").rbProfileDoc != null)
		{
			if (document.getElementById("formBusquedaAvanzada").rbProfileDoc[0].checked)
			{
				if (document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc != null)
					document.getElementById("formBusquedaAvanzada").chkNewColumnProfileDoc.checked = false;
					
				if (document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc != null)
					document.getElementById("formBusquedaAvanzada").chkLegislationProfileDoc.checked = false; 
					
				if (document.getElementById("formBusquedaAvanzada").chkJobProfileDoc != null)
					document.getElementById("formBusquedaAvanzada").chkJobProfileDoc.checked = false;
			}
		}
	}
}

function rbExtensionFile_onclick()
{
	if (document.getElementById("formBusquedaAvanzada") != null)
	{
		if (document.getElementById("formBusquedaAvanzada").rbExtensionFile != null)
		{
			if (document.getElementById("formBusquedaAvanzada").rbExtensionFile[0].checked)
			{
				if (document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile != null)
					document.getElementById("formBusquedaAvanzada").chkHtmExtensionFile.checked = false;
					
				if (document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile != null)
					document.getElementById("formBusquedaAvanzada").chkPdfExtensionFile.checked = false; 
					
				if (document.getElementById("formBusquedaAvanzada").chkDocExtensionFile != null)
					document.getElementById("formBusquedaAvanzada").chkDocExtensionFile.checked = false;			

				if (document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile != null)
					document.getElementById("formBusquedaAvanzada").chkXlsExtensionFile.checked = false;							
			}
		}
	}
}